From 7a8d8748362d4d8505e320c3eaab4a2c2463e3a6 Mon Sep 17 00:00:00 2001
From: Magnus Hagander <magnus@hagander.net>
Date: Sun, 13 Mar 2016 13:18:03 +0100
Subject: [PATCH] Rename auto_explain.sample_ratio to sample_rate

Per suggestion from Tomas Vondra

Author: Julien Rouhaud
---
 contrib/auto_explain/auto_explain.c | 10 +++++-----
 doc/src/sgml/auto-explain.sgml      | 13 ++++++-------
 2 files changed, 11 insertions(+), 12 deletions(-)

diff --git a/doc/src/sgml/auto-explain.sgml b/doc/src/sgml/auto-explain.sgml
index 6f1bde0d17e..38e6f50c802 100644
--- a/doc/src/sgml/auto-explain.sgml
+++ b/doc/src/sgml/auto-explain.sgml
@@ -206,18 +206,17 @@ LOAD 'auto_explain';
 
    <varlistentry>
     <term>
-     <varname>auto_explain.sample_ratio</varname> (<type>real</type>)
+     <varname>auto_explain.sample_rate</varname> (<type>real</type>)
      <indexterm>
-      <primary><varname>auto_explain.sample_ratio</> configuration parameter</primary>
+      <primary><varname>auto_explain.sample_rate</> configuration parameter</primary>
      </indexterm>
     </term>
     <listitem>
      <para>
-      <varname>auto_explain.sample_ratio</varname> (<type>floating point</type>)
-      causes auto_explain to only explain a fraction of the statements in each
-      session.  The default is 1, meaning explain all the queries.  In case
-      of nested statements, either all will be explained or none. Only
-      superusers can change this setting.
+      <varname>auto_explain.sample_rate</varname> causes auto_explain to only
+      explain a fraction of the statements in each session.  The default is 1,
+      meaning explain all the queries.  In case of nested statements, either all
+      will be explained or none. Only superusers can change this setting.
      </para>
     </listitem>
    </varlistentry>
diff --git a/contrib/auto_explain/auto_explain.c b/contrib/auto_explain/auto_explain.c
index 6708d817fba..fcd11a00713 100644
--- a/contrib/auto_explain/auto_explain.c
+++ b/contrib/auto_explain/auto_explain.c
@@ -29,7 +29,7 @@ static bool auto_explain_log_triggers = false;
 static bool auto_explain_log_timing = true;
 static int	auto_explain_log_format = EXPLAIN_FORMAT_TEXT;
 static bool auto_explain_log_nested_statements = false;
-static double auto_explain_sample_ratio = 1;
+static double auto_explain_sample_rate = 1;
 
 static const struct config_enum_entry format_options[] = {
 	{"text", EXPLAIN_FORMAT_TEXT, false},
@@ -163,10 +163,10 @@ _PG_init(void)
 							 NULL,
 							 NULL);
 
-	DefineCustomRealVariable("auto_explain.sample_ratio",
+	DefineCustomRealVariable("auto_explain.sample_rate",
 							 "Fraction of queries to process.",
 							NULL,
-							&auto_explain_sample_ratio,
+							&auto_explain_sample_rate,
 							1.0,
 							0.0,
 							1.0,
@@ -209,11 +209,11 @@ static void
 explain_ExecutorStart(QueryDesc *queryDesc, int eflags)
 {
 	/*
 	 * For ratio sampling, randomly choose top-level statement. Either
 	 * all nested statements will be explained or none will.
 	 */
 	if (auto_explain_log_min_duration >= 0 && nesting_level == 0)
-		current_query_sampled = (random() < auto_explain_sample_ratio *
+		current_query_sampled = (random() < auto_explain_sample_rate *
 				MAX_RANDOM_VALUE);
 
 	if (auto_explain_enabled() && current_query_sampled)
@@ -209,11 +209,11 @@ static void
 {
 	/*
-	 * For ratio sampling, randomly choose top-level statement. Either
+	 * For rate sampling, randomly choose top-level statement. Either
 	 * all nested statements will be explained or none will.
 	 */
-- 
GitLab